==> DECIPHER_2.12.0.tar.gz: DECIPHER/R/AA_REDUCED.R <==
AA_REDUCED <- list(c("A", "C", "D", "E", "FY", "G", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T", "W"),
	c("AG", "C", "DE", "FY", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T", "W"),
	c("AG", "C", "DN", "E", "FY", "H", "ILMV", "K", "P", "Q", "R", "S", "T", "W"),
	c("A", "C", "D", "E", "F", "G", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T", "W", "Y"),
	c("AG", "C", "D", "E", "FILMV", "H", "K", "N", "P", "Q", "R", "S", "T", "W", "Y"),
	c("AG", "C", "D", "E", "FWY", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T"),
	c("A", "C", "D", "E", "FY", "G", "H", "ILV", "K", "M", "N", "P", "Q", "R", "ST", "W"),
	c("A", "C", "D", "E", "FY", "G", "H", "ILV", "K", "M", "N", "P", "Q", "R", "S", "T", "W"),
	c("AG", "C", "D", "EQ", "FY", "H", "ILMV", "K", "N", "P", "R", "S", "T", "W"),
	c("AG", "C", "DN", "EQ", "FY", "H", "ILMV", "K", "P", "R", "S", "T", "W"),
	c("AS", "C", "D", "E", "FY", "G", "H", "ILV", "K", "M", "N", "P", "Q", "R", "T", "W"),
	c("A", "C", "D", "E", "F", "G", "H", "ILMV", "KR", "N", "P", "Q", "S", "T", "W", "Y"),
	c("AGILV", "CM", "DE", "FWY", "HKR", "NQ", "P", "ST"),
	c("AFILMPVW", "CGNQSTY", "DE", "HKR"),
	c("ACGPSTWY", "DEHKNQR", "FILMV"),
	c("ACGS", "DE", "FWY", "HKR", "ILV", "M", "N", "P", "Q", "T"),
	c("ACFILMVWY", "DEGHKNPQRST"),
	c("AFILMVWY", "C", "DEGHKNPQRST"),
	c("AFILMVWY", "C", "DEKR", "GHNPQST"),
	c("AFILMVWY", "C", "DE", "GHNPQST", "KR"),
	c("A", "C", "DE", "FILMVWY", "GHNPQST", "KR"),
	c("A", "C", "DE", "FILMVWY", "G", "HNPQST", "KR"),
	c("A", "C", "DE", "FILMV", "G", "HNPQST", "KR", "WY"),
	c("A", "C", "DE", "FILMV", "G", "HNQST", "KR", "P", "WY"),
	c("A", "C", "DE", "FILMV", "G", "HNQ", "KR", "P", "ST", "WY"),
	c("AST", "C", "DEN", "FY", "G", "H", "ILMV", "KQR", "P", "W"),
	c("ACFGILMPSTVWY", "DEHKNQR"),
	c("AGPST", "CILMV", "DEHKNQR", "FWY"),
	c("AG", "CILMV", "DENQ", "FWY", "H", "KR", "P", "ST"),
	c("A", "C", "DENQ", "FWY", "G", "H", "ILMV", "KR", "P", "ST"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("ADEGHKNPQRST", "CFILMVY", "W"),
	c("ADEGHKNQRST", "CFILMVY", "P", "W"),
	c("ADEGKNQRST", "CFILMVY", "H", "P", "W"),
	c("ADEGKNQRST", "C", "FILMVY", "H", "P", "W"),
	c("ADEKNQRST", "C", "FILMVY", "G", "H", "P", "W"),
	c("AEKQRST", "C", "DN", "FILMVY", "G", "H", "P", "W"),
	c("ADEGKNPQRST", "C", "FILMVWY", "H"),
	c("ADEGKNPQRST", "C", "FILMVY", "H", "W"),
	c("ADEGKNQRST", "C", "FILMVY", "H", "P", "W"),
	c("ADEKNQRST", "C", "FILMVY", "G", "H", "P", "W"),
	c("ADEKNQRST", "C", "FILMV", "G", "H", "P", "W", "Y"),
	c("ADNST", "C", "EKQR", "FILVY", "G", "H", "M", "P", "W"),
	c("ACDEGHKNPQRST", "FILMVWY"),
	c("ADEGHKNPQRST", "C", "FILMVWY"),
	c("ADEGHKNPQRST", "C", "FILMVY", "W"),
	c("AGPST", "C", "DEHKNQR", "FILMVY", "W"),
	c("AGPST", "C", "DEKNQR", "FILMVY", "H", "W"),
	c("ADGNST", "C", "EKQR", "FILMVY", "H", "P", "W"),
	c("ADGNST", "C", "EKQR", "FY", "H", "ILMV", "P", "W"),
	c("AGST", "C", "DN", "EKQR", "FY", "H", "ILMV", "P", "W"),
	c("AGST", "C", "DN", "EQ", "FY", "H", "ILMV", "KR", "P", "W"),
	c("ADEGHKNPQRST", "C", "FY", "ILMV", "W"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("APST", "CFWY", "DEHKNQR", "G", "ILMV"),
	c("AST", "CFWY", "DEQ", "G", "HN", "ILMV", "KR", "P"),
	c("AST", "C", "DEQ", "FWY", "G", "HN", "IV", "KR", "LM", "P"),
	c("AC", "DE", "FWY", "G", "HN", "IV", "KQR", "LM", "P", "ST"),
	c("AST", "CP", "DEHKNQR", "FWY", "G", "ILMV"),
	c("AST", "C", "DHN", "EKQR", "FWY", "G", "ILMV", "P"),
	c("AST", "C", "DN", "EQ", "FY", "G", "HP", "ILMV", "KR", "W"),
	c("AST", "C", "DEN", "FY", "G", "H", "ILMV", "KQR", "P", "W"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("ACGPST", "DEHKNQR", "FILMVWY"),
	c("ACGST", "DEHKNQR", "FPWY", "ILMV"),
	c("ACST", "DEKNQR", "FHWY", "GP", "ILMV"),
	c("ACST", "DEKNQR", "FHWY", "G", "ILMV", "P"),
	c("ACST", "DEN", "FWY", "G", "HKQR", "ILMV", "P"),
	c("AST", "C", "DEN", "FWY", "G", "HKQR", "ILMV", "P"),
	c("AST", "C", "DEN", "FWY", "G", "H", "ILMV", "KQR", "P"),
	c("AST", "C", "DEN", "FY", "G", "H", "ILMV", "KQR", "P", "W"),
	c("AG", "C", "DEKNPQRST", "FILMVWY", "H"),
	c("ACEFHIKLMQRVWY", "DGNPST"),
	c("AEHKQR", "CFILMVWY", "DGNPST"),
	c("AEHKQR", "CFILMVWY", "DNST", "GP"),
	c("AEHKQR", "CST", "DN", "FILMVWY", "GP"),
	c("AEKQR", "CHST", "DN", "FIV", "GP", "LMWY"),
	c("ACH", "DN", "EKQR", "FIV", "GP", "LMWY", "ST"),
	c("AM", "CF", "DNS", "EKQR", "GP", "HT", "IV", "LWY"),
	c("AMW", "CY", "DNS", "EKQR", "F", "GP", "HT", "IV", "L"),
	c("AM", "C", "DNS", "EKQR", "F", "GP", "HT", "IV", "LY", "W"),
	c("ACDEFHIKLMNQRSTVWY", "GP"),
	c("ACDEFHIKLMNQRSTVWY", "G", "P"),
	c("ADEKNQRST", "CFHILMVWY", "G", "P"),
	c("AEHKQRST", "CFILMVWY", "DN", "G", "P"),
	c("AEFHIKLMQRVWY", "CT", "DN", "G", "P", "S"),
	c("AEFIKLMQRVWY", "CH", "DN", "G", "P", "S", "T"),
	c("AEFIKLMQRVWY", "CH", "D", "G", "N", "P", "S", "T"),
	c("AEFIKLMQRVWY", "C", "D", "G", "H", "N", "P", "S", "T"),
	c("AEFIKLMQRVW", "C", "D", "G", "H", "N", "P", "S", "T", "Y"),
	c("AFILMVWY", "CDEGHKNPQRST"),
	c("AFILMVWY", "CDEHKNQRST", "GP"),
	c("ALM", "CDEHKNQRST", "FIVWY", "GP"),
	c("ALM", "CDHNST", "EKQR", "FIVWY", "GP"),
	c("ALM", "CHT", "DNS", "EKQR", "FIVWY", "GP"),
	c("A", "CHT", "DNS", "EKQR", "FIVWY", "GP", "LM"),
	c("A", "CHT", "DNS", "EKQR", "FIVWY", "G", "LM", "P"),
	c("A", "CHT", "DNS", "EKQR", "FWY", "G", "IV", "LM", "P"),
	c("A", "CH", "DNS", "EKQR", "FWY", "G", "IV", "LM", "P", "T"),
	c("AEKLMQR", "CDHNST", "FIVWY", "G", "P"),
	c("ALM", "CT", "DN", "EKQR", "FWY", "G", "HS", "IV", "P"),
	c("AV", "CFILM", "DKPQTW", "EGHNRSY"),
	c("ACFILM", "DEQR", "G", "HSV", "KNT", "P", "WY"),
	c("AV", "CFILM", "DENQ", "G", "HSTWY", "KR", "P"),
	c("AHT", "CFILMVWY", "DE", "GP", "KNQRS"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("AH", "CMVWY", "DEGNPQRST", "FIL", "K"),
	c("ACW", "DE", "FILMV", "GHNPQSTY", "KR"),
	c("AGHNPQST", "CFILMVWY", "DE", "K", "R"),
	c("AGNPQST", "C", "DE", "FILMVWY", "H", "K", "R"),
	c("ACFGHILMVWY", "DEKNPQRST"),
	c("ACFILMVWY", "DEKNPQR", "GHST"),
	c("AFHTY", "CILMV", "DEKPQ", "GNRSW"),
	c("AIS", "CHLV", "DEPQY", "FGMW", "KNRT"),
	c("ACFILMVWY", "DEGHKNPQRST"),
	c("AGHNPST", "CFILMVWY", "DEKQR"),
	c("ACHIMT", "DEKPQ", "FLVWY", "GNRS"),
	c("ACIY", "DESW", "FLMV", "GHNT", "KPQR"),
	c("AEIKLMQRV", "CDFGHNPSTWY"),
	c("AEKQR", "CFGPWY", "DHNST", "ILMV"),
	c("AEQ", "CGP", "DN", "FWY", "HST", "ILMV", "KR"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("AGHNPST", "CFILMVWY", "DEKQR"),
	c("AG", "CIV", "DEKQR", "FLMWY", "HNPST"),
	c("AG", "CIV", "DE", "FWY", "HST", "KQR", "LM", "NP"))

==> DECIPHER_2.24.0.tar.gz: DECIPHER/R/AA_REDUCED.R <==
AA_REDUCED <- list(c("A", "C", "D", "E", "FY", "G", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T", "W"),
	c("AG", "C", "DE", "FY", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T", "W"),
	c("AG", "C", "DN", "E", "FY", "H", "ILMV", "K", "P", "Q", "R", "S", "T", "W"),
	c("A", "C", "D", "E", "F", "G", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T", "W", "Y"),
	c("AG", "C", "D", "E", "FILMV", "H", "K", "N", "P", "Q", "R", "S", "T", "W", "Y"),
	c("AG", "C", "D", "E", "FWY", "H", "ILMV", "K", "N", "P", "Q", "R", "S", "T"),
	c("A", "C", "D", "E", "FY", "G", "H", "ILV", "K", "M", "N", "P", "Q", "R", "ST", "W"),
	c("A", "C", "D", "E", "FY", "G", "H", "ILV", "K", "M", "N", "P", "Q", "R", "S", "T", "W"),
	c("AG", "C", "D", "EQ", "FY", "H", "ILMV", "K", "N", "P", "R", "S", "T", "W"),
	c("AG", "C", "DN", "EQ", "FY", "H", "ILMV", "K", "P", "R", "S", "T", "W"),
	c("AS", "C", "D", "E", "FY", "G", "H", "ILV", "K", "M", "N", "P", "Q", "R", "T", "W"),
	c("A", "C", "D", "E", "F", "G", "H", "ILMV", "KR", "N", "P", "Q", "S", "T", "W", "Y"),
	c("AGILV", "CM", "DE", "FWY", "HKR", "NQ", "P", "ST"),
	c("AFILMPVW", "CGNQSTY", "DE", "HKR"),
	c("ACGPSTWY", "DEHKNQR", "FILMV"),
	c("ACGS", "DE", "FWY", "HKR", "ILV", "M", "N", "P", "Q", "T"),
	c("ACFILMVWY", "DEGHKNPQRST"),
	c("AFILMVWY", "C", "DEGHKNPQRST"),
	c("AFILMVWY", "C", "DEKR", "GHNPQST"),
	c("AFILMVWY", "C", "DE", "GHNPQST", "KR"),
	c("A", "C", "DE", "FILMVWY", "GHNPQST", "KR"),
	c("A", "C", "DE", "FILMVWY", "G", "HNPQST", "KR"),
	c("A", "C", "DE", "FILMV", "G", "HNPQST", "KR", "WY"),
	c("A", "C", "DE", "FILMV", "G", "HNQST", "KR", "P", "WY"),
	c("A", "C", "DE", "FILMV", "G", "HNQ", "KR", "P", "ST", "WY"),
	c("AST", "C", "DEN", "FY", "G", "H", "ILMV", "KQR", "P", "W"),
	c("ACFGILMPSTVWY", "DEHKNQR"),
	c("AGPST", "CILMV", "DEHKNQR", "FWY"),
	c("AG", "CILMV", "DENQ", "FWY", "H", "KR", "P", "ST"),
	c("A", "C", "DENQ", "FWY", "G", "H", "ILMV", "KR", "P", "ST"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("ADEGHKNPQRST", "CFILMVY", "W"),
	c("ADEGHKNQRST", "CFILMVY", "P", "W"),
	c("ADEGKNQRST", "CFILMVY", "H", "P", "W"),
	c("ADEGKNQRST", "C", "FILMVY", "H", "P", "W"),
	c("ADEKNQRST", "C", "FILMVY", "G", "H", "P", "W"),
	c("AEKQRST", "C", "DN", "FILMVY", "G", "H", "P", "W"),
	c("ADEGKNPQRST", "C", "FILMVWY", "H"),
	c("ADEGKNPQRST", "C", "FILMVY", "H", "W"),
	c("ADEGKNQRST", "C", "FILMVY", "H", "P", "W"),
	c("ADEKNQRST", "C", "FILMVY", "G", "H", "P", "W"),
	c("ADEKNQRST", "C", "FILMV", "G", "H", "P", "W", "Y"),
	c("ADNST", "C", "EKQR", "FILVY", "G", "H", "M", "P", "W"),
	c("ACDEGHKNPQRST", "FILMVWY"),
	c("ADEGHKNPQRST", "C", "FILMVWY"),
	c("ADEGHKNPQRST", "C", "FILMVY", "W"),
	c("AGPST", "C", "DEHKNQR", "FILMVY", "W"),
	c("AGPST", "C", "DEKNQR", "FILMVY", "H", "W"),
	c("ADGNST", "C", "EKQR", "FILMVY", "H", "P", "W"),
	c("ADGNST", "C", "EKQR", "FY", "H", "ILMV", "P", "W"),
	c("AGST", "C", "DN", "EKQR", "FY", "H", "ILMV", "P", "W"),
	c("AGST", "C", "DN", "EQ", "FY", "H", "ILMV", "KR", "P", "W"),
	c("ADEGHKNPQRST", "C", "FY", "ILMV", "W"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("APST", "CFWY", "DEHKNQR", "G", "ILMV"),
	c("AST", "CFWY", "DEQ", "G", "HN", "ILMV", "KR", "P"),
	c("AST", "C", "DEQ", "FWY", "G", "HN", "IV", "KR", "LM", "P"),
	c("AC", "DE", "FWY", "G", "HN", "IV", "KQR", "LM", "P", "ST"),
	c("AST", "CP", "DEHKNQR", "FWY", "G", "ILMV"),
	c("AST", "C", "DHN", "EKQR", "FWY", "G", "ILMV", "P"),
	c("AST", "C", "DN", "EQ", "FY", "G", "HP", "ILMV", "KR", "W"),
	c("AST", "C", "DEN", "FY", "G", "H", "ILMV", "KQR", "P", "W"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("ACGPST", "DEHKNQR", "FILMVWY"),
	c("ACGST", "DEHKNQR", "FPWY", "ILMV"),
	c("ACST", "DEKNQR", "FHWY", "GP", "ILMV"),
	c("ACST", "DEKNQR", "FHWY", "G", "ILMV", "P"),
	c("ACST", "DEN", "FWY", "G", "HKQR", "ILMV", "P"),
	c("AST", "C", "DEN", "FWY", "G", "HKQR", "ILMV", "P"),
	c("AST", "C", "DEN", "FWY", "G", "H", "ILMV", "KQR", "P"),
	c("AST", "C", "DEN", "FY", "G", "H", "ILMV", "KQR", "P", "W"),
	c("AG", "C", "DEKNPQRST", "FILMVWY", "H"),
	c("ACEFHIKLMQRVWY", "DGNPST"),
	c("AEHKQR", "CFILMVWY", "DGNPST"),
	c("AEHKQR", "CFILMVWY", "DNST", "GP"),
	c("AEHKQR", "CST", "DN", "FILMVWY", "GP"),
	c("AEKQR", "CHST", "DN", "FIV", "GP", "LMWY"),
	c("ACH", "DN", "EKQR", "FIV", "GP", "LMWY", "ST"),
	c("AM", "CF", "DNS", "EKQR", "GP", "HT", "IV", "LWY"),
	c("AMW", "CY", "DNS", "EKQR", "F", "GP", "HT", "IV", "L"),
	c("AM", "C", "DNS", "EKQR", "F", "GP", "HT", "IV", "LY", "W"),
	c("ACDEFHIKLMNQRSTVWY", "GP"),
	c("ACDEFHIKLMNQRSTVWY", "G", "P"),
	c("ADEKNQRST", "CFHILMVWY", "G", "P"),
	c("AEHKQRST", "CFILMVWY", "DN", "G", "P"),
	c("AEFHIKLMQRVWY", "CT", "DN", "G", "P", "S"),
	c("AEFIKLMQRVWY", "CH", "DN", "G", "P", "S", "T"),
	c("AEFIKLMQRVWY", "CH", "D", "G", "N", "P", "S", "T"),
	c("AEFIKLMQRVWY", "C", "D", "G", "H", "N", "P", "S", "T"),
	c("AEFIKLMQRVW", "C", "D", "G", "H", "N", "P", "S", "T", "Y"),
	c("AFILMVWY", "CDEGHKNPQRST"),
	c("AFILMVWY", "CDEHKNQRST", "GP"),
	c("ALM", "CDEHKNQRST", "FIVWY", "GP"),
	c("ALM", "CDHNST", "EKQR", "FIVWY", "GP"),
	c("ALM", "CHT", "DNS", "EKQR", "FIVWY", "GP"),
	c("A", "CHT", "DNS", "EKQR", "FIVWY", "GP", "LM"),
	c("A", "CHT", "DNS", "EKQR", "FIVWY", "G", "LM", "P"),
	c("A", "CHT", "DNS", "EKQR", "FWY", "G", "IV", "LM", "P"),
	c("A", "CH", "DNS", "EKQR", "FWY", "G", "IV", "LM", "P", "T"),
	c("AEKLMQR", "CDHNST", "FIVWY", "G", "P"),
	c("ALM", "CT", "DN", "EKQR", "FWY", "G", "HS", "IV", "P"),
	c("AV", "CFILM", "DKPQTW", "EGHNRSY"),
	c("ACFILM", "DEQR", "G", "HSV", "KNT", "P", "WY"),
	c("AV", "CFILM", "DENQ", "G", "HSTWY", "KR", "P"),
	c("AHT", "CFILMVWY", "DE", "GP", "KNQRS"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("AH", "CMVWY", "DEGNPQRST", "FIL", "K"),
	c("ACW", "DE", "FILMV", "GHNPQSTY", "KR"),
	c("AGHNPQST", "CFILMVWY", "DE", "K", "R"),
	c("AGNPQST", "C", "DE", "FILMVWY", "H", "K", "R"),
	c("ACFGHILMVWY", "DEKNPQRST"),
	c("ACFILMVWY", "DEKNPQR", "GHST"),
	c("AFHTY", "CILMV", "DEKPQ", "GNRSW"),
	c("AIS", "CHLV", "DEPQY", "FGMW", "KNRT"),
	c("ACFILMVWY", "DEGHKNPQRST"),
	c("AGHNPST", "CFILMVWY", "DEKQR"),
	c("ACHIMT", "DEKPQ", "FLVWY", "GNRS"),
	c("ACIY", "DESW", "FLMV", "GHNT", "KPQR"),
	c("AEIKLMQRV", "CDFGHNPSTWY"),
	c("AEKQR", "CFGPWY", "DHNST", "ILMV"),
	c("AEQ", "CGP", "DN", "FWY", "HST", "ILMV", "KR"),
	c("ADEGHKNPQRST", "CFILMVWY"),
	c("AGHNPST", "CFILMVWY", "DEKQR"),
	c("AG", "CIV", "DEKQR", "FLMWY", "HNPST"),
	c("AG", "CIV", "DE", "FWY", "HST", "KQR", "LM", "NP"),
	c("A", "CQ", "D", "E", "F", "G", "H", "I", "K", "L", "M", "N", "P", "R", "S", "T", "V", "W", "Y"),
	c("A", "C", "D", "E", "F", "GS", "H", "IV", "K", "L", "M", "N", "P", "Q", "R", "T", "W", "Y"),
	c("A", "C", "D", "EQS", "F", "G", "H", "IV", "K", "L", "M", "N", "P", "R", "T", "W", "Y"),
	c("AST", "C", "D", "E", "F", "G", "H", "IV", "K", "L", "M", "N", "P", "QR", "W", "Y"),
	c("A", "C", "DN", "EQR", "F", "G", "H", "IV", "K", "L", "M", "P", "ST", "W", "Y"),
	c("AST", "C", "D", "EF", "G", "H", "IV", "KQR", "L", "M", "N", "P", "W", "Y"),
	c("AST", "C", "DN", "E", "F", "G", "H", "IV", "KQR", "L", "M", "PW", "Y"),
	c("ANST", "C", "D", "E", "FY", "G", "H", "IV", "KPQR", "L", "M", "W"),
	c("ADNST", "C", "E", "FY", "G", "H", "IV", "KPQR", "L", "M", "W"),
	c("ANPST", "CY", "DE", "F", "G", "HKQR", "IV", "L", "M", "W"),
	c("AHKNPQRST", "C", "D", "E", "F", "G", "ILMV", "W", "Y"),
	c("ACHKNPQRST", "D", "E", "F", "G", "ILMV", "W", "Y"),
	c("AHKNPQRST", "CW", "D", "E", "FY", "G", "ILMV"),
	c("ACHKNPQRST", "DE", "FY", "G", "ILMV", "W"),
	c("AHKNPQRST", "CGW", "DE", "FY", "ILMV"),
	c("ADEHKNPQRST", "CGW", "FY", "ILMV"),
	c("ADEGHKNPQRST", "CILMV", "FWY"))
